# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-09-25 07:30


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0006_delete_catalogtransmissionaudit'),
    ]

    operations = [
        migrations.AlterField(
            model_name='learnerdatatransmissionaudit',
            name='enterprise_course_enrollment_id',
            field=models.PositiveIntegerField(db_index=True),
        ),
    ]
