# Generated by Django 2.2.14 on 2020-07-13 12:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0102_auto_20200708_1615'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='enterprisecourseenrollment',
            name='marked_done',
        ),
        migrations.RemoveField(
            model_name='historicalenterprisecourseenrollment',
            name='marked_done',
        ),
    ]
