# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-05-16 19:11


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0045_report_type_json'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='enterprisecustomerreportingconfiguration',
            unique_together=set([]),
        ),
    ]
